@@ -32,7 +32,7 @@ import logging
 import sys
 import os
 from threading import Lock
-
+from azureml.exceptions import ServiceException
 
 _LOCK = Lock()
 _PREFIX = None
@@ -456,9 +456,15 @@ class CompliantLogger(logging.getLoggerClass()):  # type: ignore
             description = ""
 
         # log the image
-        run.log_image(  # type: ignore
-            name=name, path=path, plot=plot, description=description
-        )
+        try:
+            run.log_image(  # type: ignore
+                name=name, path=path, plot=plot, description=description
+            )
+        except ServiceException:
+            self.warning(
+                "log_image is not available for detonation chamber, skipping.",
+                category=DataCategory.PUBLIC,
+            )
 
     def metric_list(self, name, value, description=None, category=DataCategory.PRIVATE):
         """
